@@ -13,8 +13,6 @@ class Task(BaseTask):
     request: Context
     app: "Bus"
 
-    def __call__(self, *args, **kwargs):
-        return super().__call__(*args, **kwargs)
 
 
 class Bus(Celery):
